@@ -29,6 +29,18 @@ HTML::Microformats::Format::hEvent inherits from HTML::Microformats::Format. See
 base class definition for a description of property getter/setter methods,
 constructors, etc.
 
+=head2 Additional Method
+
+=over
+
+=item * C<< to_icalendar >>
+
+This method exports the data in iCalendar format. It requires
+L<RDF::iCalendar> to work, and will throw an error at run-time
+if it's not available.
+
+=back
+
 =cut
 
 package HTML::Microformats::Format::hEvent;
@@ -40,7 +52,7 @@ use 5.008;
 use HTML::Microformats::Utilities qw(searchClass searchRel stringify);
 use HTML::Microformats::Format::species;
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 sub new
 {
@@ -191,7 +203,7 @@ sub format_signature
 		},
 		'rdf:type' => ["${ical}Vevent"] ,
 		'rdf:property' => {
-			'attach'           => { 'resource' => ["${ical}attach"] } ,
+#			'attach'           => { 'resource' => ["${ical}attach"] } ,
 			'attendee'         => { 'resource' => ["${ical}attendee"],  'literal'  => ["${icalx}attendee-literal"] } ,
 			'categories'       => { 'resource' => ["${icalx}category"], 'literal'  => ["${ical}category"] },
 			'class'            => { 'literal'  => ["${ical}class"] ,    'literal_datatype' => 'string'} ,
@@ -248,6 +260,16 @@ sub add_to_model
 		}
 	}
 
+	foreach my $val ( @{ $self->data->{attach} } )
+	{
+		$model->add_statement(RDF::Trine::Statement->new(
+			$self->id(1),
+			RDF::Trine::Node::Resource->new("${ical}attach"),
+			RDF::Trine::Node::Resource->new($val->data->{href}),
+			));
+		$val->add_to_model($model);
+	}
+
 	return $self;
 }
 
@@ -361,6 +383,15 @@ sub profiles
 	return HTML::Microformats::Format::hCalendar::profiles(@_);
 }
 
+sub to_icalendar
+{
+	my ($self) = @_;
+	die "Need RDF::iCalendar to export iCalendar data.\n"
+		unless $HTML::Microformats::Format::hCalendar::HAS_ICAL_EXPORT;
+	my $exporter = RDF::iCalendar::Exporter->new;
+	return $exporter->export_component($self->model, $self->id(1))->to_string;
+}
+
 1;
 
 =head1 BUGS
@@ -379,7 +410,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2008-2010 Toby Inkster
+Copyright 2008-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
