@@ -30,6 +30,18 @@ HTML::Microformats::Format::hFreebusy inherits from HTML::Microformats::Format.
 base class definition for a description of property getter/setter methods,
 constructors, etc.
 
+=head2 Additional Method
+
+=over
+
+=item * C<< to_icalendar >>
+
+This method exports the data in iCalendar format. It requires
+L<RDF::iCalendar> to work, and will throw an error at run-time
+if it's not available.
+
+=back
+
 =cut
 
 package HTML::Microformats::Format::hFreebusy;
@@ -42,7 +54,7 @@ use HTML::Microformats::Utilities qw(searchClass stringify);
 use HTML::Microformats::Datatype::Interval;
 use RDF::Trine;
 
-our $VERSION = '0.101';
+our $VERSION = '0.102';
 
 sub new
 {
@@ -178,6 +190,14 @@ sub profiles
 	return HTML::Microformats::Format::hCalendar::profiles(@_);
 }
 
+sub to_icalendar
+{
+	my ($self) = @_;
+	die "Need RDF::iCalendar to export iCalendar data.\n"
+		unless $HTML::Microformats::Format::hCalendar::HAS_ICAL_EXPORT;
+	my $exporter = RDF::iCalendar::Exporter->new;
+	return $exporter->export_component($self->model, $self->id(1))->to_string;
+}
 
 1;
 
@@ -197,7 +217,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2008-2010 Toby Inkster
+Copyright 2008-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
